@@ -1,6 +1,6 @@
 package Map::Tube;
 
-$Map::Tube::VERSION   = '2.72';
+$Map::Tube::VERSION   = '2.73';
 $Map::Tube::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube - Core library as Role (Moo) to process map data.
 
 =head1 VERSION
 
-Version 2.72
+Version 2.73
 
 =cut
 
@@ -416,7 +416,16 @@ sub _init_map {
         }
     }
 
-    foreach my $_line (@{$xml->{lines}->{line}}) {
+    my @lines;
+    if (exists $xml->{lines}
+        && exists $xml->{lines}->{line}) {
+
+        @lines = (ref $xml->{lines}->{line} eq 'HASH')
+            ? ($xml->{lines}->{line})
+            : @{$xml->{lines}->{line}};
+    }
+
+    foreach my $_line (@lines) {
         my $line = $_lines->{uc($_line->{name})};
         if (defined $line) {
             $line->id($_line->{id});
